@@ -30,7 +30,7 @@ import re
 import urllib2
 import socket
 
-__version__ = '0.0.33'
+__version__ = '0.0.34'
 
 def write_report(error):
     '''Function to write error to a report file'''
@@ -1476,9 +1476,9 @@ class KhweeteurWin(QMainWindow):
         self.tweetsView.custom_delegate.show_timestamp = self.settings.value("displayTimestamp").toBool()
         self.tweetsView.custom_delegate.show_avatar = self.settings.value("displayAvatar").toBool()
         self.tweetsView.custom_delegate.show_replyto = self.settings.value("displayReplyTo").toBool()
-        self.connect(self.tweetsView, SIGNAL('Clicked(const QModelIndex&)'), self.tweet_do_ask_action)
+#        self.connect(self.tweetsView, SIGNAL('Clicked(const QModelIndex&)'), self.tweet_do_ask_action)
 
-#        self.connect(self.tweetsView, SIGNAL('doubleClicked(const QModelIndex&)'), self.tweet_do_ask_action)
+        self.connect(self.tweetsView, SIGNAL('doubleClicked(const QModelIndex&)'), self.tweet_do_ask_action)
         self.tweetsModel = KhweetsModel([], self.search_keyword)
         self.tweetsView.setModel(self.tweetsModel)
         self.setCentralWidget(self.tweetsView)
